This file has too many lines (over 400). This requires refactoring to split the
file into smaller, more maintainable pieces. Ask the user for guidance on how to
refactor or split this file, as it requires architectural decisions.
